@@ -3,7 +3,7 @@ package Sah::Schema::unix::signal;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = ['str' => {
     'summary' => 'Unix signal name (e.g. TERM or KILL) or number (9 or 15)',
@@ -34,7 +34,7 @@ Sah::Schema::unix::signal - Unix signal name (e.g. TERM or KILL) or number (9 or
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::unix::signal (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
+This document describes version 0.016 of Sah::Schema::unix::signal (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -101,73 +101,73 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- undef  # INVALID
+ "HUP"  # valid
 
- undef  # INVALID
+ "INT"  # valid
 
- undef  # INVALID
+ "QUIT"  # valid
 
- undef  # INVALID
+ "ILL"  # valid
 
- undef  # INVALID
+ "ABRT"  # valid
 
- undef  # INVALID
+ "FPE"  # valid
 
- undef  # INVALID
+ "KILL"  # valid
 
- undef  # INVALID
+ "SEGV"  # valid
 
- undef  # INVALID
+ "PIPE"  # valid
 
- undef  # INVALID
+ "ALRM"  # valid
 
- undef  # INVALID
+ "TERM"  # valid
 
- undef  # INVALID
+ "USR1"  # valid
 
- undef  # INVALID
+ "USR2"  # valid
 
- undef  # INVALID
+ "CHLD"  # valid
 
- undef  # INVALID
+ "CONT"  # valid
 
- undef  # INVALID
+ "STOP"  # valid
 
- undef  # INVALID
+ "TSTP"  # valid
 
- undef  # INVALID
+ "TTIN"  # valid
 
- undef  # INVALID
+ "TTOU"  # valid
 
- undef  # INVALID
+ 1  # valid
 
- undef  # INVALID
+ 2  # valid
 
- undef  # INVALID
+ 3  # valid
 
- undef  # INVALID
+ 4  # valid
 
- undef  # INVALID
+ 5  # valid
 
- undef  # INVALID
+ 6  # valid
 
- undef  # INVALID
+ 7  # valid
 
- undef  # INVALID
+ 8  # valid
 
- undef  # INVALID
+ 9  # valid
 
- undef  # INVALID
+ 10  # valid
 
- undef  # INVALID
+ 11  # valid
 
- undef  # INVALID
+ 12  # valid
 
- undef  # INVALID
+ 13  # valid
 
- undef  # INVALID
+ 14  # valid
 
- undef  # INVALID
+ 15  # valid
 
  ""  # INVALID
 
